@@ -1,10 +1,9 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="hr">
+<TS version="2.1" language="hr" sourcelanguage="en">
 <context>
     <name>ChainPattern</name>
     <message>
-        <location filename="../src/pattern.h" line="145"/>
         <source>Chain</source>
         <translation>Lanac</translation>
     </message>
@@ -12,56 +11,17 @@
 <context>
     <name>Clock</name>
     <message>
-        <location filename="../src/clock.cpp" line="70"/>
         <source>Loading</source>
         <translation>Učitavanje</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="112"/>
         <source>Paused</source>
         <translation>Pauzirano</translation>
     </message>
 </context>
-<context>
-    <name>Definitions</name>
-    <message>
-        <location filename="../src/definitions.cpp" line="36"/>
-        <source>Definitions</source>
-        <translation>Definicija</translation>
-    </message>
-    <message>
-        <location filename="../src/definitions.cpp" line="145"/>
-        <source>Downloading definition...</source>
-        <translation>Preuzimanje definicije...</translation>
-    </message>
-    <message>
-        <location filename="../src/definitions.cpp" line="153"/>
-        <source>Unsolved word</source>
-        <translation>Neriješene riječi</translation>
-    </message>
-</context>
-<context>
-    <name>Dictionary</name>
-    <message>
-        <location filename="../src/dictionary.cpp" line="133"/>
-        <source>Definition from Wiktionary, the free dictionary</source>
-        <translation>Definicija s Wikitonary, besplatnog riječnika</translation>
-    </message>
-    <message>
-        <location filename="../src/dictionary.cpp" line="140"/>
-        <source>No definition found</source>
-        <translation>Definicija nije pronađena</translation>
-    </message>
-    <message>
-        <location filename="../src/dictionary.cpp" line="143"/>
-        <source>Unable to connect to Wiktionary</source>
-        <translation>Nije moguće povezivanje na Wikitonary</translation>
-    </message>
-</context>
 <context>
     <name>FencePattern</name>
     <message>
-        <location filename="../src/pattern.h" line="170"/>
         <source>Fence</source>
         <translation>Ograda</translation>
     </message>
@@ -69,22 +29,18 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="52"/>
         <source>Select application language:</source>
         <translation>Izaberi jezik aplikacije:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="55"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Sistemski jezik&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="173"/>
         <source>Note</source>
         <translation>Bilješka</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="173"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Molimo vas da ponovno pokrenete aplikaciju kako bi izabrani jezik bio primjenjen.</translation>
     </message>
@@ -92,55 +48,38 @@
 <context>
     <name>NewGameDialog</name>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="44"/>
         <source>New Game</source>
         <translation>Nova igra</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="57"/>
-        <location filename="../src/window.cpp" line="278"/>
         <source>Low</source>
         <translation>Lagano</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="57"/>
-        <location filename="../src/window.cpp" line="279"/>
         <source>Medium</source>
         <translation>Srednje</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="57"/>
-        <location filename="../src/window.cpp" line="280"/>
         <source>High</source>
         <translation>Teško</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="57"/>
-        <location filename="../src/window.cpp" line="281"/>
         <source>Very High</source>
         <translation>Jako teško</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="92"/>
-        <location filename="../src/window.cpp" line="292"/>
         <source>Language:</source>
         <translation>Jezik:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="94"/>
-        <location filename="../src/window.cpp" line="294"/>
         <source>Word Length:</source>
         <translation>Duljina riječi:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="93"/>
-        <location filename="../src/window.cpp" line="293"/>
         <source>Amount of Words:</source>
         <translation>Broj riječi:</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/new_game_dialog.cpp" line="142"/>
-        <location filename="../src/window.cpp" line="294"/>
         <source>%n letter(s)</source>
         <translation>
             <numerusform>%n slovo</numerusform>
@@ -152,43 +91,64 @@
 <context>
     <name>RingsPattern</name>
     <message>
-        <location filename="../src/pattern.h" line="195"/>
         <source>Rings</source>
         <translation>Prstenje</translation>
     </message>
 </context>
 <context>
-    <name>ScoreBoard</name>
+    <name>ScoresDialog</name>
     <message>
-        <location filename="../src/score_board.cpp" line="33"/>
-        <source>Scores</source>
-        <translation>Rezultati</translation>
+        <source>High Scores</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/score_board.cpp" line="37"/>
         <source>Score</source>
         <translation>Rezultat</translation>
     </message>
     <message>
-        <location filename="../src/score_board.cpp" line="37"/>
         <source>Time</source>
         <translation>Vrijeme</translation>
     </message>
     <message>
-        <location filename="../src/score_board.cpp" line="37"/>
         <source>Words</source>
         <translation>Riječi</translation>
     </message>
     <message>
-        <location filename="../src/score_board.cpp" line="37"/>
         <source>Length</source>
         <translation>Duljina</translation>
     </message>
+    <message>
+        <source>#%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StairsPattern</name>
     <message>
-        <location filename="../src/pattern.h" line="216"/>
         <source>Stairs</source>
         <translation>Stepenice</translation>
     </message>
@@ -196,7 +156,6 @@
 <context>
     <name>TwistyPattern</name>
     <message>
-        <location filename="../src/pattern.h" line="233"/>
         <source>Twisty</source>
         <translation>Uvijen</translation>
     </message>
@@ -204,7 +163,6 @@
 <context>
     <name>WavePattern</name>
     <message>
-        <location filename="../src/pattern.h" line="256"/>
         <source>Wave</source>
         <translation>Val</translation>
     </message>
@@ -212,183 +170,148 @@
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/window.cpp" line="70"/>
-        <location filename="../src/window.cpp" line="85"/>
         <source>Success</source>
         <translation>Uspijeh</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="97"/>
         <source>Loading</source>
         <translation>Učitavanje</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="97"/>
         <source>Paused</source>
         <translation>Pauzirano</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="122"/>
         <source>Definitions</source>
         <translation>Definicija</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="128"/>
         <source>Hint</source>
         <translation>Trik</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="159"/>
         <source>&amp;Game</source>
         <translation>&amp;Igra</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="160"/>
         <source>&amp;New</source>
         <translation>&amp;Novo</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="161"/>
         <source>&amp;Choose...</source>
         <translation>&amp;Izaberi</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="170"/>
         <source>&amp;Details</source>
         <translation>&amp;Detalji</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="163"/>
-        <location filename="../src/window.cpp" line="338"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pauza</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="163"/>
         <source>P</source>
         <translation>P</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="165"/>
         <source>&amp;Hint</source>
         <translation>&amp;Trik</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="165"/>
         <source>H</source>
         <translation>H</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="168"/>
         <source>D&amp;efinitions</source>
         <translation>D&amp;efinicija</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="168"/>
         <source>D</source>
         <translation>D</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="171"/>
-        <source>&amp;Scores</source>
-        <translation>&amp;Rezultati</translation>
+        <source>High &amp;Scores</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
         <source>&amp;Quit</source>
         <translation>&amp;Izlaz</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="176"/>
         <source>&amp;Settings</source>
         <translation>&amp;Postavke</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="177"/>
+        <source>&amp;Dark Mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>Application &amp;Language...</source>
         <translation>&amp;Jezik aplikacije</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="179"/>
         <source>&amp;Help</source>
         <translation>&amp;Pomoć</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="180"/>
         <source>&amp;About</source>
         <translation>O &amp;programu</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="182"/>
         <source>About &amp;Qt</source>
         <translation>O &amp;Qt-u</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="217"/>
         <source>Choose Game</source>
         <translation>Izaberi igru</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="217"/>
-        <location filename="../src/window.cpp" line="295"/>
         <source>Game Number:</source>
         <translation>Broj igre:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="221"/>
         <source>Sorry</source>
         <translation>Zao nam je!</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="221"/>
         <source>Unable to start requested game.</source>
         <translation>Nije moguće započeti novu igru.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="261"/>
         <source>About</source>
         <translation>O programu</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="30"/>
-        <location filename="../src/window.cpp" line="262"/>
         <source>Connectagram</source>
         <translation>Cennectagram</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="263"/>
         <source>A word unscrambling game</source>
         <translation>Igra premetanja riječi</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="264"/>
         <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 by Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="265"/>
         <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Objavljeno pod &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; licencom.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="266"/>
         <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
         <translation>Definicija preuzeta s &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="289"/>
         <source>Details</source>
         <translation>Detalji</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="291"/>
         <source>Pattern:</source>
         <translation>Uzorak</translation>
     </message>
-    <message>
-        <location filename="../src/window.cpp" line="338"/>
-        <source>&amp;Resume</source>
-        <translation>&amp;Nastavak</translation>
-    </message>
 </context>
 </TS>
