@@ -1,10 +1,9 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ro">
+<TS version="2.1" language="ro" sourcelanguage="en">
 <context>
     <name>ChainPattern</name>
     <message>
-        <location filename="../src/pattern.h" line="145"/>
         <source>Chain</source>
         <translation>Lanţ</translation>
     </message>
@@ -12,56 +11,17 @@
 <context>
     <name>Clock</name>
     <message>
-        <location filename="../src/clock.cpp" line="70"/>
         <source>Loading</source>
         <translation>Încarcă</translation>
     </message>
     <message>
-        <location filename="../src/clock.cpp" line="112"/>
         <source>Paused</source>
         <translation>În pauză</translation>
     </message>
 </context>
-<context>
-    <name>Definitions</name>
-    <message>
-        <location filename="../src/definitions.cpp" line="36"/>
-        <source>Definitions</source>
-        <translation>Definiţii</translation>
-    </message>
-    <message>
-        <location filename="../src/definitions.cpp" line="145"/>
-        <source>Downloading definition...</source>
-        <translation>Descărcare definiţii...</translation>
-    </message>
-    <message>
-        <location filename="../src/definitions.cpp" line="153"/>
-        <source>Unsolved word</source>
-        <translation>Cuvinte nerezolvate</translation>
-    </message>
-</context>
-<context>
-    <name>Dictionary</name>
-    <message>
-        <location filename="../src/dictionary.cpp" line="133"/>
-        <source>Definition from Wiktionary, the free dictionary</source>
-        <translation>De la Wikționar, dicționarul liber</translation>
-    </message>
-    <message>
-        <location filename="../src/dictionary.cpp" line="140"/>
-        <source>No definition found</source>
-        <translation>Nu s-a găsit nici o definiţie</translation>
-    </message>
-    <message>
-        <location filename="../src/dictionary.cpp" line="143"/>
-        <source>Unable to connect to Wiktionary</source>
-        <translation>Imposibil de conectat la Wikționar</translation>
-    </message>
-</context>
 <context>
     <name>FencePattern</name>
     <message>
-        <location filename="../src/pattern.h" line="170"/>
         <source>Fence</source>
         <translation>Îngrădire</translation>
     </message>
@@ -69,22 +29,18 @@
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="52"/>
         <source>Select application language:</source>
         <translation>Selectaţi limba aplicaţiei:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="55"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Limbaj sistem&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="173"/>
         <source>Note</source>
         <translation>Notă</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="173"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
     </message>
@@ -92,55 +48,38 @@
 <context>
     <name>NewGameDialog</name>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="44"/>
         <source>New Game</source>
         <translation>Joc nou</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="57"/>
-        <location filename="../src/window.cpp" line="278"/>
         <source>Low</source>
         <translation>Mică</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="57"/>
-        <location filename="../src/window.cpp" line="279"/>
         <source>Medium</source>
         <translation>Medie</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="57"/>
-        <location filename="../src/window.cpp" line="280"/>
         <source>High</source>
         <translation>Mare</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="57"/>
-        <location filename="../src/window.cpp" line="281"/>
         <source>Very High</source>
         <translation>Foarte mare</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="92"/>
-        <location filename="../src/window.cpp" line="292"/>
         <source>Language:</source>
         <translation>Limbă:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="94"/>
-        <location filename="../src/window.cpp" line="294"/>
         <source>Word Length:</source>
         <translation>Mărime cuvînt:</translation>
     </message>
     <message>
-        <location filename="../src/new_game_dialog.cpp" line="93"/>
-        <location filename="../src/window.cpp" line="293"/>
         <source>Amount of Words:</source>
         <translation>Cantitate de cuvinte:</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/new_game_dialog.cpp" line="142"/>
-        <location filename="../src/window.cpp" line="294"/>
         <source>%n letter(s)</source>
         <translation>
             <numerusform>%n literă</numerusform>
@@ -152,43 +91,64 @@
 <context>
     <name>RingsPattern</name>
     <message>
-        <location filename="../src/pattern.h" line="195"/>
         <source>Rings</source>
         <translation>Inele</translation>
     </message>
 </context>
 <context>
-    <name>ScoreBoard</name>
+    <name>ScoresDialog</name>
     <message>
-        <location filename="../src/score_board.cpp" line="33"/>
-        <source>Scores</source>
-        <translation>Scoruri</translation>
+        <source>High Scores</source>
+        <translation>Scoruri mari</translation>
+    </message>
+    <message>
+        <source>Rank</source>
+        <translation>Rang</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>Nume</translation>
     </message>
     <message>
-        <location filename="../src/score_board.cpp" line="37"/>
         <source>Score</source>
         <translation>Scor</translation>
     </message>
     <message>
-        <location filename="../src/score_board.cpp" line="37"/>
         <source>Time</source>
         <translation>Timp</translation>
     </message>
     <message>
-        <location filename="../src/score_board.cpp" line="37"/>
         <source>Words</source>
         <translation>Cuvinte</translation>
     </message>
     <message>
-        <location filename="../src/score_board.cpp" line="37"/>
         <source>Length</source>
         <translation>Lungime</translation>
     </message>
+    <message>
+        <source>#%1</source>
+        <translation>#%1</translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation>Felicitări!</translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation>Ţi-ai bătut cel mai bun scor!</translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation>Felicitări!</translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation>Ai un nou scor mare!</translation>
+    </message>
 </context>
 <context>
     <name>StairsPattern</name>
     <message>
-        <location filename="../src/pattern.h" line="216"/>
         <source>Stairs</source>
         <translation>Trepte</translation>
     </message>
@@ -196,7 +156,6 @@
 <context>
     <name>TwistyPattern</name>
     <message>
-        <location filename="../src/pattern.h" line="233"/>
         <source>Twisty</source>
         <translation>Contorsionat</translation>
     </message>
@@ -204,7 +163,6 @@
 <context>
     <name>WavePattern</name>
     <message>
-        <location filename="../src/pattern.h" line="256"/>
         <source>Wave</source>
         <translation>Ondulat</translation>
     </message>
@@ -212,183 +170,148 @@
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/window.cpp" line="70"/>
-        <location filename="../src/window.cpp" line="85"/>
         <source>Success</source>
         <translation>Succes</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="97"/>
         <source>Loading</source>
         <translation>Încarcă</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="97"/>
         <source>Paused</source>
         <translation>În pauză</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="122"/>
         <source>Definitions</source>
         <translation>Definiţii</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="128"/>
         <source>Hint</source>
         <translation>Indiciu</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="159"/>
         <source>&amp;Game</source>
         <translation>&amp;Joc</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="160"/>
         <source>&amp;New</source>
         <translation>&amp;Nou</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="161"/>
         <source>&amp;Choose...</source>
         <translation>Alegeţi...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="170"/>
         <source>&amp;Details</source>
         <translation>&amp;Detalii</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="163"/>
-        <location filename="../src/window.cpp" line="338"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pauză</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="163"/>
         <source>P</source>
         <translation>P</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="165"/>
         <source>&amp;Hint</source>
         <translation>Indiciu</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="165"/>
         <source>H</source>
         <translation>H</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="168"/>
         <source>D&amp;efinitions</source>
         <translation>D&amp;efiniţii</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="168"/>
         <source>D</source>
         <translation>D</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="171"/>
-        <source>&amp;Scores</source>
-        <translation>&amp;Scoruri</translation>
+        <source>High &amp;Scores</source>
+        <translation>&amp;Scoruri mari</translation>
+    </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation>Ctrl+H</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
         <source>&amp;Quit</source>
         <translation>&amp;Ieşire</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="176"/>
         <source>&amp;Settings</source>
         <translation>&amp;Setări</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="177"/>
+        <source>&amp;Dark Mode</source>
+        <translation>Mod Întunecat</translation>
+    </message>
+    <message>
         <source>Application &amp;Language...</source>
         <translation>Limbă aplicaţie...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="179"/>
         <source>&amp;Help</source>
         <translation>&amp;Ajutor</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="180"/>
         <source>&amp;About</source>
         <translation>&amp;Despre</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="182"/>
         <source>About &amp;Qt</source>
         <translation>Despre &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="217"/>
         <source>Choose Game</source>
         <translation>Alegeţi joc</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="217"/>
-        <location filename="../src/window.cpp" line="295"/>
         <source>Game Number:</source>
         <translation>Joc număr:</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="221"/>
         <source>Sorry</source>
         <translation>Scuze</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="221"/>
         <source>Unable to start requested game.</source>
         <translation>Nu se poate începe jocul solicitat.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="261"/>
         <source>About</source>
         <translation>Despre</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="30"/>
-        <location filename="../src/window.cpp" line="262"/>
         <source>Connectagram</source>
         <translation>Connectagram</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="263"/>
         <source>A word unscrambling game</source>
         <translation>Un joc de descîlcire de cuvinte</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="264"/>
         <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
         <translation>Toate drepturile rezervate &amp;copy; 2009-%1 by Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="265"/>
         <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Lansat sub licenţă &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="266"/>
         <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
         <translation>Definiţiile sînt de la &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wikționar&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="289"/>
         <source>Details</source>
         <translation>Detalii</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="291"/>
         <source>Pattern:</source>
         <translation>Model:</translation>
     </message>
-    <message>
-        <location filename="../src/window.cpp" line="338"/>
-        <source>&amp;Resume</source>
-        <translation>&amp;Reluare</translation>
-    </message>
 </context>
 </TS>
